@@ -1,7 +1,7 @@
 '''File for handling all operations relating to the US Core Condition resource'''
 
 from fhirgenerator.resources.r4.condition import generateCondition
-
+from fhir.resources.condition import Condition
 
 def generateUSCoreCondition(detail: dict, patient_id: str, start_date: str, days: str):
     '''Generate a US Core Condition'''
@@ -10,4 +10,7 @@ def generateUSCoreCondition(detail: dict, patient_id: str, start_date: str, days
     condition_resource['meta'] = {'profile': ['http://hl7.org/fhir/us/core/StructureDefinition/us-core-condition']}
     condition_resource['clinicalStatus'] = {'coding': [{'system': 'http://terminology.hl7.org/CodeSystem/condition-clinical', 'code': 'active', 'display': 'Active'}]}
     condition_resource['category'] = [{'coding': [{'system': 'http://terminology.hl7.org/CodeSystem/condition-category', 'code': 'problem-list-item'}]}]
+
+    condition_resource = Condition(**condition_resource).dict()
+
     return condition_resource
