@@ -1,6 +1,7 @@
 '''File for handling all operations relating to the US Core Head Circumference Observation resource'''
 
 from fhirgenerator.resources.r4.observation import generateObservation
+from fhir.resources.observation import Observation
 
 
 def generateUSCoreHeadCircumferenceObservation(detail: dict, patient_id: str, start_date: str, days: str) -> dict:
@@ -15,4 +16,6 @@ def generateUSCoreHeadCircumferenceObservation(detail: dict, patient_id: str, st
         "display": "Vital Signs"
     }]}]
 
+    observation_resource = Observation(**observation_resource).dict()
+
     return observation_resource
