@@ -1,7 +1,7 @@
 '''File for handling all operations relating to the US Core Heart Rate Observation resource'''
 
 from fhirgenerator.resources.r4.observation import generateObservation
-
+from fhir.resources.observation import Observation
 
 def generateUSCoreHeartRateObservation(detail: dict, patient_id: str, start_date: str, days: str) -> dict:
     '''Generate a US Core Heart Rate Observation'''
@@ -15,4 +15,6 @@ def generateUSCoreHeartRateObservation(detail: dict, patient_id: str, start_date
         "display": "Vital Signs"
     }]}]
 
+    observation_resource = Observation(**observation_resource).dict()
+
     return observation_resource
