@@ -17,3 +17,13 @@ def generateMRNIdentifier() -> dict:
         'value': fake.ssn()
     }
     return identifier_dict
+
+
+def generateSSNIdentifier() -> dict:
+    '''Generate a Patient.identifier for a SSN'''
+    fake = Faker()
+    identifier_dict = {
+        'system': 'http://hl7.org/fhir/sid/us-ssn',
+        'value': fake.ssn()
+    }
+    return identifier_dict
